@@ -14,11 +14,11 @@ Games::Cards::ShuffleTrack - Track cards through shuffles and cuts
 
 =head1 VERSION
 
-Version 0.01
+Version 0.01_2
 
 =cut
 
-our $VERSION = '0.01_1';
+our $VERSION = '0.01_2';
 
 our $cut_limits = {
 	normal	=> [0.19, 0.82], # on a 52 cards deck, cut between 10 and 43 cards
@@ -99,7 +99,9 @@ As an example, some card representations:
 
 =head1 SUBROUTINES/METHODS
 
-=head2 new
+=head2 Standard methods
+
+=head3 new
 
 Create a new deck.
 
@@ -140,7 +142,7 @@ sub new {
 }
 
 
-=head2 get_deck
+=head3 get_deck
 
 Returns the deck (a reference to a list of strings).
 
@@ -166,20 +168,24 @@ Riffle shuffle the deck.
 
 In the act of riffle shuffling a deck the deck is cut into two halves of approximately the same size; each half is riffled so that the cards of both halves interlace; these cards usually drop in groups of 1 to 5 cards.
 
+You can also decide where to cut the deck for the shuffle:
+
+	$deck->riffle_shuffle( 'short' );  # closer to the top
+	$deck->riffle_shuffle( 'center' ); # near the center
+	$deck->riffle_shuffle( 'deep' );   # closer to the bottom
+	$deck->riffle_shuffle( 26 );       # precisely under the 26th card
+
 =cut
 
 # TODO: add an option for an out-shuffle
 # TODO: add an option to control top or bottom stock
-# TODO: add an option to select where the deck is cut before the shuffle
 # TODO: when dropping cards, should we favor numbers 2 and 3?
 sub riffle_shuffle {
-	my $self = shift;
+	my $self  = shift;
+	my $depth = shift;
 
 	# cut the deck (left pile is the original top half)
-	my $size = $self->_deck_size;
-
-	# we're cutting somewhere between 18 and 31 cards
-	my $cut_depth = _rand( $size * 0.35, $size * 0.60 );
+	my $cut_depth = _cut_depth( $self->_deck_size, $depth );
 
 	my @left_pile  = @{$self->get_deck};
 	my @right_pile = splice @left_pile, $cut_depth;
@@ -230,7 +236,7 @@ In a "faro in" the top and bottom cards do not remain in their original position
 
 Considering the positions on the cards from 1 to 52 the result of the faro would be as follows:
 
-	27, 1, 28, 2, 29, 3, 30, 4, 31, 5, 32, 6, 33, 7, ...
+    27, 1, 28, 2, 29, 3, 30, 4, 31, 5, 32, 6, 33, 7, ...
 
 =cut
 
@@ -266,34 +272,71 @@ Cut at a precise position (moving X cards from top to bottom):
 
     $deck->cut(26);
 
+If you try to cut to a position that doesn't exist nothing will happen (apart from a warning that you tried to cut to a non-existing position, of course).
+
+You can also cut at negative positions, meaning that you're counting from the bottom of the deck and cutting above that card. For instance, to cut the bottom two cards to the top:
+
+	$deck->cut(-2);
+
 Additional ways of cutting:
 
-	$deck->cut( 'short'  ); # on a 52 cards deck, somewhere between 5  and 15 cards
-	$deck->cut( 'center' ); # on a 52 cards deck, somewhere between 19 and 31 cards
-	$deck->cut( 'deep'   ); # on a 52 cards deck, somewhere between 35 and 45 cards
+    $deck->cut( 'short'  ); # on a 52 cards deck, somewhere between 5  and 15 cards
+    $deck->cut( 'center' ); # on a 52 cards deck, somewhere between 19 and 31 cards
+    $deck->cut( 'deep'   ); # on a 52 cards deck, somewhere between 35 and 45 cards
+
+=head3 cut_below
+
+You can cut below a specific card.
+
+	$deck->cut_below( '9D' );
+
+If the desired card is already on the bottom of the deck nothing will happen.
+
+For more information on how to cut to a specific card please refer to the L<SEE ALSO> section of this documentation.
+
+=head3 cut_above
+
+You can cut above a specific card.
+
+	$deck->cut_above( 'JS' );
+
+If the desired card is already on top of the deck nothing will happen.
+
+For more information on how to cut to a specific card please refer to the L<SEE ALSO> section of this documentation.
 
 =cut
 
 sub cut {
-	my $self = shift;
-	my $position = shift; # TODO: what happens if the position doesn't exist?
+	my $self     = shift;
+	my $position = shift;
 
-	if (not defined $position) {
-		$position = 'normal';
+	if (defined $position and abs($position) > $self->_deck_size) {
+		warn "Tried to cut the deck at a non-existing position ($position).\n";
+		return $self;
 	}
 
-	if ($position =~ /^short|center|deep|normal$/) {
-		my ($lower, $upper) = @{$cut_limits->{ $position }};
-		my $size = $self->_deck_size;
-		$position = _rand( $size * $lower, $size * $upper );
-	}
+	my $cut_depth = _cut_depth( $self->_deck_size, $position );
 
 	my @deck = @{$self->get_deck};
-	unshift @deck, splice @deck, $position;
+	unshift @deck, splice @deck, $cut_depth;
 
 	return $self->_set_deck( @deck );
 }
 
+sub cut_below {
+	my $self = shift;
+	my $card = shift;
+
+	return $self->cut( $self->find( $card ) );
+}
+
+sub cut_above {
+	my $self = shift;
+	my $card = shift;
+
+	return $self->cut( $self->find( $card ) - 1 );
+}
+
 
 =head2 Finding cards
 
@@ -315,6 +358,10 @@ You can also request a card in a negative position (i.e., from the bottom of the
 
     $deck->find( -2 );
 
+If you're dealing five hands of poker from the top of the deck, for instance, you can easily find which cards will fall on the dealer's hand:
+
+    $deck->find( 5, 10, 15, 20, 25 );
+
 =cut
 
 sub find {
@@ -328,8 +375,8 @@ sub find {
     for my $card ( @cards ) {
 
     	push @results, looks_like_number( $card )
-    					? $self->_find_card_by_position( $card )
-    					: $self->_find_card_by_name( $card );
+    				 ? $self->_find_card_by_position( $card )
+    				 : $self->_find_card_by_name( $card );
 
     }
 
@@ -443,6 +490,22 @@ sub _rand {
 	return int($lower_limit + int(rand( $upper_limit - $lower_limit )));
 }
 
+sub _cut_depth {
+	my $deck_size = shift;
+	my $position  = shift;
+
+	if (not defined $position) {
+		$position = 'normal';
+	}
+
+	if ($position =~ /^short|center|deep|normal$/) {
+		my ($lower, $upper) = @{$cut_limits->{ $position }};
+		$position = _rand( $deck_size * $lower, $deck_size * $upper );
+	}
+
+	return $position;
+}
+
 
 =head1 AUTHOR
 
@@ -481,9 +544,13 @@ L<http://search.cpan.org/dist/Games-Cards-ShuffleTrack/>
 
 Recommended reading:
 
-    * The Expert at the Card Table: The Classic Treatise on Card Manipulation, by S. W. Erdnase
+=over 4
 
-    * The Annotated Erdnase, by Darwin Ortiz
+=item * The Expert at the Card Table: The Classic Treatise on Card Manipulation, by S. W. Erdnase
+
+=item * The Annotated Erdnase, by Darwin Ortiz
+
+=back
 
 
 =head1 LICENSE AND COPYRIGHT
